tty

package
v1.37.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 17, 2026 License: AGPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsInteractive

func IsInteractive() bool

IsInteractive returns true if stderr is a terminal. We check stderr (not stdout) because stdout may be piped for data output while stderr remains the user's terminal for progress/TUI.

func StderrIsTerminal

func StderrIsTerminal() bool

StderrIsTerminal returns true if stderr is connected to a terminal.

func StdoutIsTerminal

func StdoutIsTerminal() bool

StdoutIsTerminal returns true if stdout is connected to a terminal.

Types

This section is empty.

Jump to